function f = opt(x, g, eta, P, L, lambda)

% Solve the optimization problem as Equation (9) in Socioscope paper. 

% Substitute g into the eta function and change the variable to theta = log(f).
eta_theta = @(theta)eta(exp(theta), g);

% Initialization. 
% Find the theta0, which minimizes || x - P*eta(exp(theta), g) ||_2
eta0 = max(P\x, 1e-4);
% Optimization options. Can be changed for your problem.
options = optimset('GradObj','on', 'LargeScale', 'off', 'MaxIter', 1000, 'Display', 'off');
theta0 = fsolve(@(theta)eta_theta(theta) - eta0, rand(size(P, 2), 1), options);

% Call the optimization solver.
theta = fminunc(@objfunc, theta0, options);

% Return the recovered target phenomenon intensity
f = exp(theta);

%--------------- the nested objective function ---------------------------
function [obj,grad] = objfunc(theta)

   [eta_fval, eta_grad] = eta_theta(theta);
   h = P * eta_fval;
   
   % the objective function value
   obj = sum(h - x.*log(h)) + lambda/2*theta'*L*theta;
   
   % the gradient
   grad = lambda*L*theta - P'*(x./h-1).*(eta_grad.*exp(theta));

end
%--------------- the nested objective function ----------------------------

end
